
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef E_MAIL_ENGINE_ENUMTYPES_H
#define E_MAIL_ENGINE_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "e-mail-engine-enums.h" */
#define E_TYPE_MAIL_LOCAL_FOLDER	(e_mail_local_folder_get_type())
GType e_mail_local_folder_get_type	(void) G_GNUC_CONST;
#define E_TYPE_MAIL_RECIPIENT_CERTIFICATE_LOOKUP	(e_mail_recipient_certificate_lookup_get_type())
GType e_mail_recipient_certificate_lookup_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_MAIL_ENGINE_ENUMTYPES_H */

/* Generated data ends here */

